@@ -87,9 +87,14 @@ CSG_Grid * SG_Create_Grid(const char       *File, TSG_Data_Type Type, bool bCach
 CSG_Grid * SG_Create_Grid(const wchar_t    *File, TSG_Data_Type Type, bool bCached, bool bLoadData) { return( SG_Create_Grid(CSG_String(File), Type, bCached, bLoadData) ); }
 CSG_Grid * SG_Create_Grid(const CSG_String &File, TSG_Data_Type Type, bool bCached, bool bLoadData)
 {
-	CSG_Grid *pGrid = new CSG_Grid(File, Type, bCached, bLoadData);
+	CSG_Grid *pGrid = new CSG_Grid();
 
-	if( !pGrid->is_Valid() ) { delete(pGrid); return( NULL ); } return( pGrid );
+	if( pGrid->Create(File, Type, bCached, bLoadData) )
+	{
+		return( pGrid );
+	}
+
+	delete(pGrid); return( NULL );
 }
 
 //---------------------------------------------------------
@@ -231,12 +236,13 @@ bool CSG_Grid::Create(const CSG_Grid &Grid)
 {
 	if( Create(Grid.Get_System(), Grid.Get_Type()) )
 	{
-		Set_Name              (Grid.Get_Name       ());
-		Set_Description       (Grid.Get_Description());
-		Set_Unit              (Grid.Get_Unit       ());
-		Set_NoData_Value_Range(Grid.Get_NoData_Value(), Grid.Get_NoData_Value(true));
-		Set_Scaling           (Grid.Get_Scaling(), Grid.Get_Offset());
-		Get_MetaData().Create (Grid.Get_MetaData());
+		Set_Name               (Grid.Get_Name       ());
+		Set_Description        (Grid.Get_Description());
+		Set_Unit               (Grid.Get_Unit       ());
+		Set_NoData_Value_Range (Grid.Get_NoData_Value(), Grid.Get_NoData_Value(true));
+		Set_Scaling            (Grid.Get_Scaling(), Grid.Get_Offset());
+		Get_MetaData  ().Create(Grid.Get_MetaData   ());
+		Get_Projection().Create(Grid.Get_Projection ());
 
 		#pragma omp parallel for
 		for(int y=0; y<Get_NY(); y++) for(int x=0; x<Get_NX(); x++)
@@ -266,8 +272,10 @@ bool CSG_Grid::Create(CSG_Grid *pGrid, TSG_Data_Type Type, bool bCached)
 }
 
 //---------------------------------------------------------
-bool CSG_Grid::Create(const CSG_Grid_System &System, TSG_Data_Type Type, bool bCached)
+bool CSG_Grid::Create(const CSG_Grid_System &_System, TSG_Data_Type Type, bool bCached)
 {
+	CSG_Grid_System System(_System); // just in case _System is identical with this->m_System
+
 	Destroy();
 
 	switch( (m_Type = Type) )
@@ -298,7 +306,7 @@ bool CSG_Grid::Create(const CSG_Grid_System &System, TSG_Data_Type Type, bool bC
 	m_Statistics.Invalidate();
 
 	m_nBytes_Value = SG_Data_Type_Get_Size(m_Type);
-	m_nBytes_Line  = m_Type == SG_DATATYPE_Bit ? 1 + Get_NX() / 8 : Get_NX() * m_nBytes_Value;
+	m_nBytes_Line  = m_Type == SG_DATATYPE_Bit ? 1 + (size_t)Get_NX() / 8 : (size_t)Get_NX() * m_nBytes_Value;
 
 	Set_Max_Samples(SG_DataObject_Get_Max_Samples() > 0 ? SG_DataObject_Get_Max_Samples() : Get_NCells());
 
